==> java-sdk-4.15.1-sources.jar: com/baidu/aip/imagesearch/ImageSearchConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.imagesearch;

public class ImageSearchConsts {

    static final String SAME_HQ_ADD =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/add";

    static final String SAME_HQ_SEARCH =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/search";

    static final String SAME_HQ_UPDATE =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/update";

    static final String SAME_HQ_DELETE =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/delete";

    static final String SIMILAR_ADD =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/add";

    static final String SIMILAR_SEARCH =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/search";

    static final String SIMILAR_UPDATE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/update";

    static final String SIMILAR_DELETE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/delete";

    static final String PRODUCT_ADD =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/add";

    static final String PRODUCT_SEARCH =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/search";

    static final String PRODUCT_UPDATE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/update";

    static final String PRODUCT_DELETE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/delete";


    static final String PICTUREBOOKADD = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/add";

    static final String PICTUREBOOKSEARCH = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/search";

    static final String PICTUREBOOKDELETE = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/delete";

    static final String PICTUREBOOKUPDATE = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/update";

}

==> java-sdk-4.16.17-sources.jar: com/baidu/aip/imagesearch/ImageSearchConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.imagesearch;

public class ImageSearchConsts {


    static final String MATERIEL_ADD =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/materiel/add";

    static final String MATERIEL_SEARCH =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/materiel/search";

    static final String MATERIEL_UPDATE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/materiel/update";

    static final String MATERIEL_DELETE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/materiel/delete";

    static final String SAME_HQ_ADD =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/add";

    static final String SAME_HQ_SEARCH =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/search";

    static final String SAME_HQ_UPDATE =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/update";

    static final String SAME_HQ_DELETE =
            "https://aip.baidubce.com/rest/2.0/realtime_search/same_hq/delete";

    static final String SIMILAR_ADD =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/add";

    static final String SIMILAR_SEARCH =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/search";

    static final String SIMILAR_UPDATE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/update";

    static final String SIMILAR_DELETE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/similar/delete";

    static final String PRODUCT_ADD =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/add";

    static final String PRODUCT_SEARCH =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/search";

    static final String PRODUCT_UPDATE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/update";

    static final String PRODUCT_DELETE =
            "https://aip.baidubce.com/rest/2.0/image-classify/v1/realtime_search/product/delete";


    static final String PICTUREBOOKADD = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/add";

    static final String PICTUREBOOKSEARCH = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/search";

    static final String PICTUREBOOKDELETE = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/delete";

    static final String PICTUREBOOKUPDATE = "https://aip.baidubce.com/rest/2.0/imagesearch/v1/realtime_search/picturebook/update";

}
